#ifndef WAYPOINTLISTDELEGATE_H
#define WAYPOINTLISTDELEGATE_H

#include <QStyledItemDelegate>

#include <rx/columbus/ColumbusModel.h>
#include <rx/columbus/ColumbusWaypointModel.h>

class WaypointListDelegatePrivate;

class WaypointListDelegate : public QStyledItemDelegate
{
    Q_OBJECT

public:
    explicit WaypointListDelegate(ColumbusModel *model, ColumbusWaypointModel *waypoints, QObject *parent = 0);
            ~WaypointListDelegate();

    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;

private:
    WaypointListDelegatePrivate *d;
};

#endif // WAYPOINTLISTDELEGATE_H
